Page Menu
Home
FreeBSD
Search
Configure Global Search
Log In
Files
F169307394
D901.id1893.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Flag For Later
Award Token
Size
2 KB
Referenced Files
None
Subscribers
None
D901.id1893.diff
View Options
Index: Mk/Scripts/check-stagedir.sh
===================================================================
--- Mk/Scripts/check-stagedir.sh
+++ Mk/Scripts/check-stagedir.sh
@@ -88,7 +88,7 @@
;;
esac
;;
- # Handle [dirrmtry] Keywords
+ # Handle [dir] Keywords
@fc\ *|@fcfontsdir\ *|@fontsdir\ *)
set -- $line
shift
@@ -220,14 +220,14 @@
# Used for generate_plist
sed_files_gen="s!${PREFIX}/!!g; ${sed_plist_sub} \
${sed_portdocsexamples} /^share\/licenses/d;"
- sed_dirs_gen="s!${PREFIX}/!!g; ${sed_plist_sub} s,^,@dirrmtry ,; \
+ sed_dirs_gen="s!${PREFIX}/!!g; ${sed_plist_sub} s,^,@dir ,; \
${sed_portdocsexamples} \
- /^@dirrmtry share\/licenses/d;"
+ /^@dir share\/licenses/d;"
# These prevent ignoring DOCS/EXAMPLES dirs with sed_portdocsexamples
sed_files="s!${PREFIX}/!!g; ${sed_plist_sub} /^share\/licenses/d;"
- sed_dirs="s!${PREFIX}/!!g; ${sed_plist_sub} s,^,@dirrmtry ,; \
- /^@dirrmtry share\/licenses/d;"
+ sed_dirs="s!${PREFIX}/!!g; ${sed_plist_sub} s,^,@dir ,; \
+ /^@dir share\/licenses/d;"
}
@@ -264,16 +264,16 @@
# Handle whitelisting
while read path; do
case "${path}" in
- *'@dirrmtry '[^/]*) ;;
+ *'@dir '[^/]*) ;;
*.bak) ;;
*.orig) ;;
*/.DS_Store) ;;
*/.cvsignore) ;;
- */.git/*|'@dirrmtry '*/.git) ;;
+ */.git/*|'@dir '*/.git) ;;
*/.gitattributes|*/.gitignore|*/.gitmodules) ;;
- */.svn/*|'@dirrmtry '*/.svn) ;;
+ */.svn/*|'@dir '*/.svn) ;;
*/.svnignore) ;;
- */CVS/*|'@dirrmtry '*/CVS) ;;
+ */CVS/*|'@dir '*/CVS) ;;
*/info/dir|info/dir) ;;
lib/X11/fonts/*/fonts.dir) ;;
lib/X11/fonts/*/fonts.scale) ;;
Index: Mk/Scripts/check_leftovers.sh
===================================================================
--- Mk/Scripts/check_leftovers.sh
+++ Mk/Scripts/check_leftovers.sh
@@ -66,11 +66,11 @@
ignore_path=0
sub_path=$(echo "$path" | sed -e "s|^${PREFIX}/||" -e "${plistsub_sed}")
orig_sub_path="${sub_path}"
# If this is a directory, use @dirrm in output
is_dir=0
if [ -d "${path}" ]; then
is_dir=1
- sub_path="@dirrm ${sub_path}"
+ sub_path="@dir ${sub_path}"
fi
# Handle PORTDOCS/PORTEXAMPLES/etc
@@ -153,7 +153,7 @@
/etc/pwd.db|\
/etc/shells|\
/etc/spwd.db) ;;
- *) echo "M ${sub_path#@dirrm } ${extra}" ;;
+ *) echo "M ${sub_path#@dir } ${extra}" ;;
esac
;;
esac
@@ -66,11 +66,11 @@
sub_path=$(echo "$path" | sed -e "s|^${PREFIX}/||" -e "${plistsub_sed}")
orig_sub_path="${sub_path}"
- # If this is a directory, use @dirrm in output
+ # If this is a directory, use @dir in output
is_dir=0
if [ -d "${path}" ]; then
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Wed, Sep 2, 4:17 AM (10 h, 34 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
37902327
Default Alt Text
D901.id1893.diff (2 KB)
Attached To
Mode
D901: Replace dirrm with dir in makeplist and leftover check
Attached
Detach File
Event Timeline
Log In to Comment